@@ -1,5 +1,5 @@
 package Time::Random;
-use 5.006; use strict; use warnings; our $VERSION = '1.01';
+use 5.006; use strict; use warnings; our $VERSION = '1.02';
 use Time::Piece;
 use base 'Import::Export';
 our %EX = (
@@ -30,7 +30,7 @@ Time::Random - Generate a random time in time.
 
 =head1 VERSION
 
-Version 1.01
+Version 1.02
 
 =cut
 
@@ -139,14 +139,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Time-Random>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Time-Random>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Time-Random>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/Time-Random/>
@@ -158,7 +150,7 @@ L<http://search.cpan.org/dist/Time-Random/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2018->2024 lnation.
+Copyright 2018->2025 lnation.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
